#include "Application.h"

/* --- CODE SPACE -----------------------------------------------------------------------------------------*/
#include <Pragma_Section_Start_text_code.h>

uint32_T NullFault(void)
{
  return 4;
}

boolean_T IsFaultValid(uint32_T fault)
{
  return (fault < 4);
}

boolean_T IsFaultEnabled(uint32_T fault)
{
  uint8_T mode;
  if (fault >= 4)
    return 0;
  mode = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->mode;
  return (mode != 0);
}

boolean_T IsFaultSuspected(uint32_T fault)
{
  uint8_T mask;
  if (fault >= 4)
    return 0;
  mask = (uint8_T) (1U << (fault & 7U));
  return (VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0;
}

boolean_T IsFaultActive(uint32_T fault)
{
  uint8_T mask;
  if (fault >= 4)
    return 0;
  mask = (uint8_T) (1U << (fault & 7U));
  return (VolFaultManager_DataStore_VolFaultManager().active & mask) != 0;
}

boolean_T IsFaultOccurred(uint32_T fault)
{
  uint8_T mask;
  if (fault >= 4)
    return 0;
  mask = (uint8_T) (1U << (fault & 7U));
  return (VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0;
}

void RefreshFaultActionReferenceCounts()
{
  int32_T fault;
  uint8_T action;
  for (action=0; action < 4; action++) {
    ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))->reference_count =
      0;
  }

  for (fault=0; fault < 4; fault++) {
    uint8_T mask;
    mask = (uint8_T) (1U << (fault & 7U));

    {
      boolean_T s = (VolFaultManager_DataStore_VolFaultManager().suspected &
                     mask) != 0;
      boolean_T a = (VolFaultManager_DataStore_VolFaultManager().active & mask)
        != 0;
      boolean_T o = (VolFaultManager_DataStore_VolFaultManager().occurred & mask)
        != 0;
      uint8_T cond;

      {
        cond = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action1_condition;
        action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action1;
        if (action < 4) {
          if (s && (cond & FAULT_COND_SUSPECTED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (a && (cond & FAULT_COND_ACTIVE)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (o && (cond & FAULT_COND_OCCURRED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }
        }
      }

      {
        cond = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action2_condition;
        action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action2;
        if (action < 4) {
          if (s && (cond & FAULT_COND_SUSPECTED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (a && (cond & FAULT_COND_ACTIVE)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (o && (cond & FAULT_COND_OCCURRED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }
        }
      }

      {
        cond = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action3_condition;
        action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action3;
        if (action < 4) {
          if (s && (cond & FAULT_COND_SUSPECTED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (a && (cond & FAULT_COND_ACTIVE)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (o && (cond & FAULT_COND_OCCURRED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }
        }
      }

      {
        cond = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action4_condition;
        action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->action4;
        if (action < 4) {
          if (s && (cond & FAULT_COND_SUSPECTED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (a && (cond & FAULT_COND_ACTIVE)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }

          if (o && (cond & FAULT_COND_OCCURRED)) {
            ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
              ->reference_count++;
          }
        }
      }
    }
  }
}

void AdjustFaultActionReferenceCount(uint32_T fault, boolean_T val, uint8_T
  condition)
{
  uint8_T action;
  if (fault >= 4)
    return;

  /* Adjust the fault action reference count for each action condition set in the calibration */
  {
    if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action1_condition & condition) {
      action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action1;
      if (action < 4) {
        if (val) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count++;
        } else if (((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
                   ->reference_count) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count--;
        }
      }
    }
  }

  {
    if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action2_condition & condition) {
      action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action2;
      if (action < 4) {
        if (val) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count++;
        } else if (((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
                   ->reference_count) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count--;
        }
      }
    }
  }

  {
    if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action3_condition & condition) {
      action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action3;
      if (action < 4) {
        if (val) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count++;
        } else if (((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
                   ->reference_count) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count--;
        }
      }
    }
  }

  {
    if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action4_condition & condition) {
      action = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
        ->action4;
      if (action < 4) {
        if (val) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count++;
        } else if (((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
                   ->reference_count) {
          ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
            ->reference_count--;
        }
      }
    }
  }
}

void OnChangeFaultSuspected(uint32_T fault, boolean_T val)
{
  if (fault >= 4)
    return;
  AdjustFaultActionReferenceCount(fault, val, FAULT_COND_SUSPECTED);
  if (val) {
    VolFaultManager_DataStore_VolFaultManager().last_suspected_fault = (uint8_T)
      fault;
  } else {
    VolFaultManager_DataStore_VolFaultManager().last_unsuspected_fault =
      (uint8_T) fault;
  }
}

void OnChangeFaultActive(uint32_T fault, boolean_T val)
{
  if (fault >= 4)
    return;
  AdjustFaultActionReferenceCount(fault, val, FAULT_COND_ACTIVE);
  if (val) {
    VolFaultManager_DataStore_VolFaultManager().last_active_fault = (uint8_T)
      fault;
  } else {
    VolFaultManager_DataStore_VolFaultManager().last_inactive_fault = (uint8_T)
      fault;
  }
}

void OnChangeFaultOccurred(uint32_T fault, boolean_T val)
{
  if (fault >= 4)
    return;
  AdjustFaultActionReferenceCount(fault, val, FAULT_COND_OCCURRED);
  if (val) {
    VolFaultManager_DataStore_VolFaultManager().last_occurred_fault = (uint8_T)
      fault;
  }
}

void SetFaultSuspected(uint32_T fault, boolean_T val)
{
  uint8_T mask;
  boolean_T old;
  if (fault >= 4)
    return;
  mask = (uint8_T) (1U << (fault & 7U));
  old = (VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0;
  if (val != old) {
    if (val) {
      VolFaultManager_DataStore_VolFaultManager().suspected |= mask;
    } else {
      VolFaultManager_DataStore_VolFaultManager().suspected &= ~mask;
    }

    OnChangeFaultSuspected(fault, val);
  }
}

void SetFaultActive(uint32_T fault, boolean_T val)
{
  uint8_T mask;
  boolean_T old;
  if (fault >= 4)
    return;
  mask = (uint8_T) (1U << (fault & 7U));
  old = (VolFaultManager_DataStore_VolFaultManager().active & mask) != 0;
  if (val != old) {
    if (val) {
      VolFaultManager_DataStore_VolFaultManager().active |= mask;
    } else {
      VolFaultManager_DataStore_VolFaultManager().active &= ~mask;
    }

    OnChangeFaultActive(fault, val);
  }
}

void SetFaultOccurred(uint32_T fault, boolean_T val)
{
  uint8_T mask;
  boolean_T old;
  if (fault >= 4)
    return;
  mask = (uint8_T) (1U << (fault & 7U));
  old = (VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0;
  if (val != old) {
    if (val) {
      VolFaultManager_DataStore_VolFaultManager().occurred |= mask;
    } else {
      VolFaultManager_DataStore_VolFaultManager().occurred &= ~mask;
    }

    OnChangeFaultOccurred(fault, val);
  }
}

uint32_T GetLastSuspectedFault(void)
{
  return VolFaultManager_DataStore_VolFaultManager().last_suspected_fault;
}

uint32_T GetLastUnsuspectedFault(void)
{
  return VolFaultManager_DataStore_VolFaultManager().last_unsuspected_fault;
}

uint32_T GetLastActiveFault(void)
{
  return VolFaultManager_DataStore_VolFaultManager().last_active_fault;
}

uint32_T GetLastInactiveFault(void)
{
  return VolFaultManager_DataStore_VolFaultManager().last_inactive_fault;
}

uint32_T GetLastOccurredFault(void)
{
  return VolFaultManager_DataStore_VolFaultManager().last_occurred_fault;
}

uint32_T GetNextFault(uint32_T fault, boolean_T loop)
{
  if (fault == 3) {
    if (!loop)
      return 4;
    fault = 0;
  } else if (fault > 3) {
    fault = 0;
  } else {
    fault++;
  }

  return fault;
}

uint32_T GetNextEnabledFault(uint32_T fault, boolean_T loop)
{
  uint8_T count;
  if (fault == 3) {
    if (!loop)
      return 4;
    fault = 0;
  } else if (fault > 3) {
    fault = 0;
  } else {
    fault++;
  }

  count = 0;
  while (count < 4) {
    if (IsFaultEnabled(fault)) {
      return fault;
    }

    fault++;
    if (fault >= 4) {
      if (loop) {
        fault = 0;
      } else {
        return 4;
      }
    }

    count++;
  }

  return 4;
}

uint32_T GetNextSuspectedFault(uint32_T fault, boolean_T loop)
{
  uint8_T count;
  if (fault == 3) {
    if (!loop)
      return 4;
    fault = 0;
  } else if (fault > 3) {
    fault = 0;
  } else {
    fault++;
  }

  count = 0;
  while (count < 4) {
    if (IsFaultSuspected(fault)) {
      return fault;
    }

    fault++;
    if (fault >= 4) {
      if (loop) {
        fault = 0;
      } else {
        return 4;
      }
    }

    count++;
  }

  return 4;
}

uint32_T GetNextActiveFault(uint32_T fault, boolean_T loop)
{
  uint8_T count;
  if (fault == 3) {
    if (!loop)
      return 4;
    fault = 0;
  } else if (fault > 3) {
    fault = 0;
  } else {
    fault++;
  }

  count = 0;
  while (count < 4) {
    if (IsFaultActive(fault)) {
      return fault;
    }

    fault++;
    if (fault >= 4) {
      if (loop) {
        fault = 0;
      } else {
        return 4;
      }
    }

    count++;
  }

  return 4;
}

uint32_T GetNextOccurredFault(uint32_T fault, boolean_T loop)
{
  uint8_T count;
  if (fault == 3) {
    if (!loop)
      return 4;
    fault = 0;
  } else if (fault > 3) {
    fault = 0;
  } else {
    fault++;
  }

  count = 0;
  while (count < 4) {
    if (IsFaultOccurred(fault)) {
      return fault;
    }

    fault++;
    if (fault >= 4) {
      if (loop) {
        fault = 0;
      } else {
        return 4;
      }
    }

    count++;
  }

  return 4;
}

void ClearFault(uint32_T fault)
{
  if (fault >= 4)
    return;
  ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->x = 0;
  ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->y = 0;
  SetFaultSuspected(fault, 0);
  SetFaultActive(fault, 0);
  SetFaultOccurred(fault, 0);
}

void UpdateFault(uint32_T fault)
{
  uint8_T mode;
  uint32_T xlim;
  uint32_T ylim;
  uint32_T x;
  uint32_T y;
  boolean_T s;
  boolean_T a;
  boolean_T o;
  uint8_T mask;
  if (fault >= 4)
    return;
  mode = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->mode;

  /* If disabled, the input signal is considered zero, and the x/y counters should be cleared */
  if (mode <= FAULT_MODE_DISABLED) {
    s = 0;
    a = 0;
    o = 0;
    x = 0;
    y = 0;
  } else {
    mask = (uint8_T) (1U << (fault & 7U));
    xlim = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->xlim;
    ylim = ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->ylim;
    x = ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->x;
    y = ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->y;
    s = ((VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0);
    a = ((VolFaultManager_DataStore_VolFaultManager().active & mask) != 0);
    o = ((VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0);

    /* Set suspected status during test */
    s |= ((boolean_T) ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
          ->test);

    /* X/Y Fault Counter Mechanism */
    if (a) {
      if ((mode == FAULT_MODE_STICKY) ||
          (mode == FAULT_MODE_STICKYDASHPERSISTENT)) {
        x = 0;
        y = 0;
      } else {
        if (s) {
          x = 0;
          y = 0;
        } else {
          y++;
        }
      }
    } else {
      if (s) {
        x++;
      }

      if (x > 0) {
        y++;
      }

      if ((xlim - x) > (ylim - y)) {
        x = 0;
        y = 0;
      }
    }

    /* Check counters and change states */
    if (x >= xlim) {
      a = 1;
      x = 0;
      y = 0;
    } else if (y >= ylim) {
      /* Go inactive and become occurred, unlesss sticky */
      if ((mode != FAULT_MODE_STICKY) &&
          (mode != FAULT_MODE_STICKYDASHPERSISTENT)) {
        if (a) {
          o = 1;
        }

        a = 0;
      }

      x = 0;
      y = 0;
    }
  }

  /* Set status bits, and update counters */
  ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->x = (uint8_T) x;
  ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->y = (uint8_T) y;
  SetFaultSuspected(fault, s);
  SetFaultActive(fault, a);
  SetFaultOccurred(fault, o);
}

void ResetFaultXY(uint32_T fault)
{
  if (fault >= 4)
    return;

  /* Reset X/Y Counters to Zero */
  ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->x = 0;
  ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault]))->y = 0;
}

boolean_T GetFaultProperties(uint32_T fault,
  uint32_T *out_id, uint8_T *out_mode,
  uint32_T *out_xlim, uint32_T *out_ylim,
  uint32_T *out_x, uint32_T *out_y)
{
  if (fault >= 4) {
    if (out_id)
      *out_id = 0;
    if (out_mode)
      *out_mode = 0;
    if (out_xlim)
      *out_xlim = 0;
    if (out_ylim)
      *out_ylim = 0;
    if (out_x)
      *out_x = 0;
    if (out_y)
      *out_y = 0;
    return 0;
  } else {
    if (out_id)
      *out_id = (uint32_T) ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore())
        [fault]))->id;
    if (out_mode)
      *out_mode = (uint8_T) ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore())
        [fault]))->mode;
    if (out_xlim)
      *out_xlim = (uint32_T) ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore())
         [fault]))->xlim;
    if (out_ylim)
      *out_ylim = (uint32_T) ((S_ConstFault_T *) ( (ConstFaultsRef_DataStore())
         [fault]))->ylim;
    if (out_x)
      *out_x = (uint32_T) ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault])
        )->x;
    if (out_y)
      *out_y = (uint32_T) ((S_Fault_T *) ( (VolFaultsRef_DataStore()) [fault])
        )->y;
    return 1;
  }
}

const char *GetFaultName(uint32_T fault)
{
  return 0;
}

uint8_T GetActionCondForFaultAction(uint32_T fault, uint8_T action)
{
  if (fault >= 4 || action >= 4)
    return 0;
  if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->action1 ==
       action) && (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault])
                   )->action1_condition > 0)) {
    return (uint8_T)(((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
                     ->action1_condition);
  } else if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
              ->action2 == action) && (((S_ConstFault_T *)
               ( (ConstFaultsRef_DataStore()) [fault]))->action2_condition > 0))
  {
    return (uint8_T)(((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
                     ->action2_condition);
  } else if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
              ->action3 == action) && (((S_ConstFault_T *)
               ( (ConstFaultsRef_DataStore()) [fault]))->action3_condition > 0))
  {
    return (uint8_T)(((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
                     ->action3_condition);
  } else if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
              ->action4 == action) && (((S_ConstFault_T *)
               ( (ConstFaultsRef_DataStore()) [fault]))->action4_condition > 0))
  {
    return (uint8_T)(((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
                     ->action4_condition);
  } else {
    return 0;
  }
}

boolean_T GetFaultActionStatus(uint32_T action)
{
  if (action >= 4)
    return 0;
  return (((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
          ->reference_count > 0);
}

void GlobalFaultClear(void)
{
  {
    uint32_T index;
    for (index=0; index < 4; index++) {
      ClearFault(index);
    }

    for (index=0; index < 1; index++) {
      VolFaultManager_DataStore_VolFaultManager().suspected = 0;
      VolFaultManager_DataStore_VolFaultManager().active = 0;
      VolFaultManager_DataStore_VolFaultManager().occurred = 0;
    }
  }

  {
    uint32_T action;
    for (action=0; action < 4; action++) {
      ((S_FaultAction_T *) ( (ActionsRef_DataStore()) [action]))
        ->reference_count = 0;
    }
  }

  FaultMarquees_DataStore_FaultMarquees().current_suspected_vardec = 4;
  FaultMarquees_DataStore_FaultMarquees().current_active_vardec = 4;
  FaultMarquees_DataStore_FaultMarquees().current_occurred_vardec = 4;
  VolFaultManager_DataStore_VolFaultManager().last_suspected_fault = 4;
  VolFaultManager_DataStore_VolFaultManager().last_unsuspected_fault = 4;
  VolFaultManager_DataStore_VolFaultManager().last_active_fault = 4;
  VolFaultManager_DataStore_VolFaultManager().last_inactive_fault = 4;
  VolFaultManager_DataStore_VolFaultManager().last_occurred_fault = 4;
}

static void UpdateSuspectedMarquee(void)
{
  FaultMarquees_DataStore_FaultMarquees().current_suspected_vardec = (uint8_T)
    GetNextSuspectedFault(FaultMarquees_DataStore_FaultMarquees().
    current_suspected_vardec, 1);
}

static void UpdateActiveMarquee(void)
{
  FaultMarquees_DataStore_FaultMarquees().current_active_vardec = (uint8_T)
    GetNextActiveFault(FaultMarquees_DataStore_FaultMarquees().
                       current_active_vardec, 1);
}

static void UpdateOccurredMarquee(void)
{
  FaultMarquees_DataStore_FaultMarquees().current_occurred_vardec = (uint8_T)
    GetNextOccurredFault(FaultMarquees_DataStore_FaultMarquees().
    current_occurred_vardec, 1);
}

static void UpdateActionReasonMarquee(uint32_T fault_action_index)
{
  typedef struct {
    uint8_T fault_index;
  } fault_action_marquee_state_t;

  static fault_action_marquee_state_t fault_action_marquee_state[4] = { { 0 } };

  uint8_T fault;
  uint8_T count;
  if (GetFaultActionStatus(fault_action_index)) {
    fault = fault_action_marquee_state[fault_action_index].fault_index;
    count = 0;
    while (count < 4) {
      uint8_T mask;
      fault++;
      if (fault >= 4) {
        fault = 0;
      }

      mask = (uint8_T) (1U << (fault & 7U));
      if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->action1==
          fault_action_index) {
        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action1_condition & FAULT_COND_SUSPECTED) &&
            ((VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action1_condition & FAULT_COND_ACTIVE) &&
            ((VolFaultManager_DataStore_VolFaultManager().active & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action1_condition & FAULT_COND_OCCURRED) &&
            ((VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }
      }

      if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->action2==
          fault_action_index) {
        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action2_condition & FAULT_COND_SUSPECTED) &&
            ((VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action2_condition & FAULT_COND_ACTIVE) &&
            ((VolFaultManager_DataStore_VolFaultManager().active & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action2_condition & FAULT_COND_OCCURRED) &&
            ((VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }
      }

      if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->action3==
          fault_action_index) {
        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action3_condition & FAULT_COND_SUSPECTED) &&
            ((VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action3_condition & FAULT_COND_ACTIVE) &&
            ((VolFaultManager_DataStore_VolFaultManager().active & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action3_condition & FAULT_COND_OCCURRED) &&
            ((VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }
      }

      if (((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))->action4==
          fault_action_index) {
        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action4_condition & FAULT_COND_SUSPECTED) &&
            ((VolFaultManager_DataStore_VolFaultManager().suspected & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action4_condition & FAULT_COND_ACTIVE) &&
            ((VolFaultManager_DataStore_VolFaultManager().active & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }

        if ((((S_ConstFault_T *) ( (ConstFaultsRef_DataStore()) [fault]))
             ->action4_condition & FAULT_COND_OCCURRED) &&
            ((VolFaultManager_DataStore_VolFaultManager().occurred & mask) != 0))
        {
          (FaultActionReason_DataStore())[fault_action_index] = fault;
          fault_action_marquee_state[fault_action_index].fault_index = fault;
          return;
        }
      }

      count++;
    }
  }

  (FaultActionReason_DataStore())[fault_action_index] = 4;
}

void FaultManagerPeriodicTick(void)
{
  /* Handle Command VarDec from MotoTune */
  if ((FaultCommand_DataStore()) == FAULT_COMMAND_CLEARALLFAULTS) {
    GlobalFaultClear();
  }

  (FaultCommand_DataStore()) = FAULT_COMMAND_DASH;

  /* Update VarDec Marquees */
  UpdateSuspectedMarquee();
  UpdateActiveMarquee();
  UpdateOccurredMarquee();

  {
    uint32_T i;
    for (i=0; i < 4; i++) {
      UpdateActionReasonMarquee(i);
    }
  }
}

/*---- END OF FILE ----------------------------------------------------------------------------------------*/
